@@ -28,7 +28,7 @@
 #include <errno.h>
 #include <stdlib.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include "nm-mobile-providers.h"
 
